==> haskell-unagi-streams-0.2.7-115-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unagi-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unagi-streams
version:              0.2.7
visibility:           public
id:                   unagi-streams-0.2.7-2p71e4V7suqG1AVIpgvzsJ
key:                  unagi-streams-0.2.7-2p71e4V7suqG1AVIpgvzsJ
license:              BSD-3-Clause
copyright:            Bitnomial, Inc. (c) 2016
maintainer:           luke@bitnomial.com
author:               Luke Hoersten
homepage:             https://github.com/bitnomial/unagi-streams
synopsis:             Unagi Chan IO-Streams
description:
    Io-streams chans implemented underneath with
    unagi-chans. This library is a straight port of
    the default io-streams chan implementation.

category:             IO-Streams, Concurrency
abi:                  055d0777c0fcf18635e30021b9464520
exposed:              True
exposed-modules:
    System.IO.Streams.Concurrent.Unagi
    System.IO.Streams.Concurrent.Unagi.Bounded

import-dirs:          /usr/lib/ghc-9.4.8/site-local/unagi-streams-0.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unagi-streams-0.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unagi-streams-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unagi-streams
hs-libraries:         HSunagi-streams-0.2.7-2p71e4V7suqG1AVIpgvzsJ
depends:
    base-4.17.2.1 io-streams-1.5.2.2-C922vE7sC8ZE1UuSOYKgyJ
    unagi-chan-0.4.1.4-75imrwnpCsZCokM1wNgOAe

haddock-interfaces:
    /usr/share/doc/haskell-unagi-streams/html/unagi-streams.haddock

haddock-html:         /usr/share/doc/haskell-unagi-streams/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unagi-streams-0.2.7-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unagi-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unagi-streams
version:              0.2.7
visibility:           public
id:                   unagi-streams-0.2.7-6btDnMXVmSQHh9cGtnDfSa
key:                  unagi-streams-0.2.7-6btDnMXVmSQHh9cGtnDfSa
license:              BSD-3-Clause
copyright:            Bitnomial, Inc. (c) 2016
maintainer:           luke@bitnomial.com
author:               Luke Hoersten
homepage:             https://github.com/bitnomial/unagi-streams
synopsis:             Unagi Chan IO-Streams
description:
    Io-streams chans implemented underneath with
    unagi-chans. This library is a straight port of
    the default io-streams chan implementation.

category:             IO-Streams, Concurrency
abi:                  1924daf2a6b3a8bc2f5085219d806ec5
exposed:              True
exposed-modules:
    System.IO.Streams.Concurrent.Unagi
    System.IO.Streams.Concurrent.Unagi.Bounded

import-dirs:          /usr/lib/ghc-9.4.8/site-local/unagi-streams-0.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unagi-streams-0.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unagi-streams-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unagi-streams
hs-libraries:         HSunagi-streams-0.2.7-6btDnMXVmSQHh9cGtnDfSa
depends:
    base-4.17.2.1 io-streams-1.5.2.2-70PBcrLuCYi7r9XY6o77CA
    unagi-chan-0.4.1.4-8eMIpsb5gqj1nRimaS8Ktj

haddock-interfaces:
    /usr/share/doc/haskell-unagi-streams/html/unagi-streams.haddock

haddock-html:         /usr/share/doc/haskell-unagi-streams/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
